@@ -1,6 +1,6 @@
-# mod_11_10.py - functions for performing the ISO 7064 Mod 11, 10 algorithm
+# mod_37_36.py - functions for performing the ISO 7064 Mod 37, 36 algorithm
 #
-# Copyright (C) 2010, 2011, 2012, 2013 Arthur de Jong
+# Copyright (C) 2010-2021 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,55 +17,60 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""The ISO 7064 Mod 11, 10 algorithm.
+"""The ISO 7064 Mod 37, 36 algorithm.
 
-The Mod 11, 10 algorithm uses a number of calculations modulo 11 and 10 to
-determine a checksum.
+The Mod 37, 36 algorithm uses an alphanumeric check digit and the number
+itself may also contain letters.
 
-For a module that can do generic Mod x+1, x calculations see the
-:mod:`stdnum.iso7064.mod_37_36` module.
+>>> checksum('A12425GABC1234002M')
+1
+>>> calc_check_digit('A12425GABC1234002')
+'M'
+>>> validate('A12425GABC1234002M')
+'A12425GABC1234002M'
 
->>> calc_check_digit('79462')
-'3'
->>> validate('794623')
-'794623'
->>> calc_check_digit('00200667308')
+By changing the alphabet this can be turned into any Mod x+1, x
+algorithm. For example Mod 11, 10:
+
+>>> calc_check_digit('00200667308', alphabet='0123456789')
 '5'
->>> validate('002006673085')
+>>> validate('002006673085', alphabet='0123456789')
 '002006673085'
 """
 
 from stdnum.exceptions import *
 
 
-def checksum(number):
+def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Calculate the checksum. A valid number should have a checksum of 1."""
-    check = 5
+    modulus = len(alphabet)
+    check = modulus // 2
     for n in number:
-        check = (((check or 10) * 2) % 11 + int(n)) % 10
+        check = (((check or modulus) * 2) % (modulus + 1) + alphabet.index(n)) % modulus
     return check
 
 
-def calc_check_digit(number):
+def calc_check_digit(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Calculate the extra digit that should be appended to the number to
     make it a valid number."""
-    return str((1 - ((checksum(number) or 10) * 2) % 11) % 10)
+    modulus = len(alphabet)
+    return alphabet[(1 - ((checksum(number, alphabet) or modulus) * 2) % (modulus + 1)) % modulus]
 
 
-def validate(number):
+def validate(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Check whether the check digit is valid."""
     try:
-        valid = checksum(number) == 1
-    except Exception:
+        valid = checksum(number, alphabet) == 1
+    except Exception:  # noqa: B902
         raise InvalidFormat()
     if not valid:
         raise InvalidChecksum()
     return number
 
 
-def is_valid(number):
+def is_valid(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Check whether the check digit is valid."""
     try:
-        return bool(validate(number))
+        return bool(validate(number, alphabet))
     except ValidationError:
         return False
