@@ -1,7 +1,7 @@
 # util.py - common utility functions
 # coding: utf-8
 #
-# Copyright (C) 2012-2018 Arthur de Jong
+# Copyright (C) 2012-2021 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -35,9 +35,14 @@ import warnings
 from stdnum.exceptions import *
 
 
+# Regular expression to match doctests in docstrings
 _strip_doctest_re = re.compile(r'^>>> .*\Z', re.DOTALL | re.MULTILINE)
 
 
+# Regular expression to match digits
+_digits_re = re.compile(r'^[0-9]+$')
+
+
 def _mk_char_map(mapping):
     """Transform a dictionary with comma separated uniode chracter names
     to tuples with unicode characters as key."""
@@ -96,6 +101,55 @@ _char_map = dict(_mk_char_map({
     'PUNCTUATION SPACE,THIN SPACE,HAIR SPACE,NARROW NO-BREAK SPACE,'
     'MEDIUM MATHEMATICAL SPACE,IDEOGRAPHIC SPACE':
         ' ',
+    'FULLWIDTH DIGIT ZERO,MATHEMATICAL BOLD DIGIT ZERO,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO,MATHEMATICAL SANS-SERIF DIGIT ZERO,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO,MATHEMATICAL MONOSPACE DIGIT ZERO':
+        '0',
+    'FULLWIDTH DIGIT ONE,MATHEMATICAL BOLD DIGIT ONE,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT ONE,MATHEMATICAL SANS-SERIF DIGIT ONE,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT ONE,MATHEMATICAL MONOSPACE DIGIT ONE':
+        '1',
+    'FULLWIDTH DIGIT TWO,MATHEMATICAL BOLD DIGIT TWO,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT TWO,MATHEMATICAL SANS-SERIF DIGIT TWO,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT TWO,MATHEMATICAL MONOSPACE DIGIT TWO':
+        '2',
+    'FULLWIDTH DIGIT THREE,MATHEMATICAL BOLD DIGIT THREE,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT THREE,MATHEMATICAL SANS-SERIF DIGIT THREE,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT THREE,MATHEMATICAL MONOSPACE DIGIT THREE':
+        '3',
+    'FULLWIDTH DIGIT FOUR,MATHEMATICAL BOLD DIGIT FOUR,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR,MATHEMATICAL SANS-SERIF DIGIT FOUR,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR,MATHEMATICAL MONOSPACE DIGIT FOUR':
+        '4',
+    'FULLWIDTH DIGIT FIVE,MATHEMATICAL BOLD DIGIT FIVE,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE,MATHEMATICAL SANS-SERIF DIGIT FIVE,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE,MATHEMATICAL MONOSPACE DIGIT FIVE':
+        '5',
+    'FULLWIDTH DIGIT SIX,MATHEMATICAL BOLD DIGIT SIX,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT SIX,MATHEMATICAL SANS-SERIF DIGIT SIX,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT SIX,MATHEMATICAL MONOSPACE DIGIT SIX':
+        '6',
+    'FULLWIDTH DIGIT SEVEN,MATHEMATICAL BOLD DIGIT SEVEN,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN,MATHEMATICAL SANS-SERIF DIGIT SEVEN,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN,MATHEMATICAL MONOSPACE DIGIT SEVEN':
+        '7',
+    'FULLWIDTH DIGIT EIGHT,MATHEMATICAL BOLD DIGIT EIGHT,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT,MATHEMATICAL SANS-SERIF DIGIT EIGHT,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT,MATHEMATICAL MONOSPACE DIGIT EIGHT':
+        '8',
+    'FULLWIDTH DIGIT NINE,MATHEMATICAL BOLD DIGIT NINE,'
+    'MATHEMATICAL DOUBLE-STRUCK DIGIT NINE,MATHEMATICAL SANS-SERIF DIGIT NINE,'
+    'MATHEMATICAL SANS-SERIF BOLD DIGIT NINE,MATHEMATICAL MONOSPACE DIGIT NINE':
+        '9',
+    'APOSTROPHE,GRAVE ACCENT,ACUTE ACCENT,MODIFIER LETTER RIGHT HALF RING,'
+    'MODIFIER LETTER LEFT HALF RING,MODIFIER LETTER PRIME,'
+    'MODIFIER LETTER TURNED COMMA,MODIFIER LETTER APOSTROPHE,'
+    'MODIFIER LETTER VERTICAL LINE,COMBINING GRAVE ACCENT,'
+    'COMBINING ACUTE ACCENT,COMBINING TURNED COMMA ABOVE,'
+    'COMBINING COMMA ABOVE,ARMENIAN APOSTROPHE,'
+    'SINGLE HIGH-REVERSED-9 QUOTATION MARK,LEFT SINGLE QUOTATION MARK,'
+    'RIGHT SINGLE QUOTATION MARK':
+        "'",
 }))
 
 
@@ -114,7 +168,7 @@ def clean(number, deletechars=''):
     """
     try:
         number = ''.join(x for x in number)
-    except Exception:
+    except Exception:  # noqa: B902
         raise InvalidFormat()
     if sys.version < '3' and isinstance(number, str):  # pragma: no cover (Python 2 specific code)
         try:
@@ -129,6 +183,13 @@ def clean(number, deletechars=''):
     return ''.join(x for x in number if x not in deletechars)
 
 
+def isdigits(number):
+    """Check whether the provided string only consists of digits."""
+    # This function is meant to replace str.isdigit() which will also return
+    # True for all kind of unicode digits which is generally not what we want
+    return bool(_digits_re.match(number))
+
+
 def to_unicode(text):
     """Convert the specified text to a unicode string."""
     if not isinstance(text, type(u'')):
